@@ -7,12 +7,14 @@ from urllib import request
 
 IPV4_PATTERN = re.compile(r"\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}")
 
-if os.name == "posix":
-    root = "~"
-else:
-    root = os.environ.get("USERPROFILE", "C:")
+# if os.name == "posix":
+#     root = "~"
+# else:
+#     root = os.environ.get("USERPROFILE", "C:")
+#
+# root = os.path.join(root, '.websocks')
 
-root = os.path.join(root, '.websocks')
+root = os.path.dirname(os.path.abspath(__file__))
 
 if not os.path.exists(root):
     os.makedirs(root)
